#
# spec file for package python-subliminal
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-subliminal
Version:        2.2.1
Release:        1.4
Summary:        Python library to search and download subtitles
License:        MIT
URL:            https://github.com/Diaoul/subliminal
Source:         https://files.pythonhosted.org/packages/source/s/subliminal/subliminal-%{version}.tar.gz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools  >= 18.0.1}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-babelfish >= 0.6.1
Requires:       python-beautifulsoup4 >= 4.4.0
Requires:       python-chardet >= 5.0
Requires:       python-click >= 8.0
Requires:       python-click-option-group >= 0.5.6
Requires:       python-dogpile.cache >= 1.0
Requires:       python-enzyme >= 0.5.0
Requires:       python-guessit >= 3.0.0
Requires:       python-platformdirs >= 3
Requires:       python-pysubs2 >= 1.7
Requires:       python-rarfile >= 2.7
Requires:       python-requests >= 2.7.0
Requires:       python-srt >= 3.5
Requires:       python-stevedore >= 3.0
Requires:       python-tomli >= 2
Requires(post): update-alternatives
Requires(postun): update-alternatives
Recommends:     python-colorlog >= 2.6.0
Provides:       subliminal = %{version}
Obsoletes:      subliminal < %{version}
BuildArch:      noarch
%python_subpackages

%description
Subliminal is a python library to search and download subtitles.
It comes with an easy to use CLI suitable for direct use or cron jobs.

%prep
%autosetup -n subliminal-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_clone -a %{buildroot}%{_bindir}/subliminal
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check

%post
%python_install_alternative subliminal

%postun
%python_uninstall_alternative subliminal

%files %{python_files}
%license LICENSE
%doc HISTORY.rst README.rst
%python_alternative %{_bindir}/subliminal
%{python_sitelib}/subliminal
%{python_sitelib}/subliminal-%{version}.dist-info

%changelog
* Fri Jun 28 2024 Luigi Baldoni <aloisio@gmx.com>
- Update to version 2.2.1
  * Relax the version bounds on platformdirs to >= 3
  * Show config message only in debug mode in CLI
  * Add example subliminal.toml to docs and various docs fixes
* Tue Jun 25 2024 Luigi Baldoni <aloisio@gmx.com>
- Update to version 2.2.0
  * Drop python2 support, the supported versions are
    >=3.8,<=3.12.
  * Load CLI options from a configuration file with the
  - -config/-c option
  * Change default encoding of downloaded subtitles to 'utf-8'
    (not the original encoding). Use the --original-encoding cli
    option to recover the previous default behavior
  * Add opensubtitlescom provider
  * Add gestdown provider
  * Add tmdb refiner (requires a personal API key)
  * Fix tvsubtitles provider
  * Fix opensubtitles provider
  * Fix napiprojekt provider
  * Fix podnapisi provider to use JSON API
  * Fix addic7ed provider
  * Remove thesubdb provider
  * Remove argenteam provider
  * Remove shooter provider
  * Remove legendastv provider
  * Use pyproject.toml to specify the package configurations.
  * Add pre-commit hook
  * Use ruff to lint and format
  * Use mypy to check types
  * Add type annotations
  * Drop dependencies: pysrt, appdirs, six, pytz
  * Add dependencies:
    + click-option-group>=0.5.6
    + platformdirs>=4.2
    + pysubs2>=1.7
    + srt>=3.5
    + tomli>=2
  * Bump dependency versions:
    + babelfish>=0.6.1
    + chardet>=5.0
    + click>=8.0
    + dogpile.cache>=1.0
    + enzyme>=0.5.0
    + stevedore>=3.0
* Wed Mar 30 2022 Luigi Baldoni <aloisio@gmx.com>
- Build only for default python3 version
* Tue May 19 2020 Petr Gajdos <pgajdos@suse.com>
- %%python3_only -> %%python_alternative
* Sat May  2 2020 Luigi Baldoni <aloisio@gmx.com>
- Update to version 2.1.0
  * Improve legendastv provider matches
  * Fix video extensions (.mk3d .ogm .ogv)
  * Use new url to search for titles in legendastv provider
  * Fix stevedore incompatibility
  * Add support to webm video extension
  * Make providers easier to be extended and customized
  * Update podnapisi URL
  * Add support to VIP/Donor accounts in legendastv provider
  * Proper handling titles with year / country in legendastv
    provider
  * Several minor enhancements in legendastv provider
  * Add support for python 3.6, 3.7 and 3.8
  * Drop support for python 3.3 and 3.4
  * Do not discard providers bad zip/rar is downloaded
  * SubsCenter provider removal
  * Fix lxml parsing for Addic7ed provider
  * Support titles with asterics in Addic7ed provider
  * Add support to multi-episode search in Opensubtitles provider
  * Fix multi-episode search in TVSubtitles provider
  * Update to guessit 3
  * Improve archive scanning
  * Add Opensubtitles VIP provider
  * Add country to Movie and Episode
  * Add streaming_service to Video
  * Add info property to Subtitle
  * Do not search for subtitles if all required languages is
    already present
  * Improve TVDB refiner to support series with comma
  * Add alternative_titles to Video and enhance OMDB refiner to
    use alternative_titles
  * Only compute video hashes when required
  * Add apikey to OMDB refiner
  * Fix Subtitle validation when unable to guess encoding
  * Add support to rar in Dockerfile
- Drop python2 support to simplify packaging
- Drop subliminal.1 manpage because it's no longer possible to
  build it
* Mon Oct 14 2019 Matej Cepl <mcepl@suse.com>
- Replace %%fdupes -s with plain %%fdupes; hardlinks are better.
* Thu Jul 13 2017 aloisio@gmx.com
- Obtained correct tarball
* Thu Jul 13 2017 aloisio@gmx.com
- Converted to single-spec
- Switched source URL to pypi
- Ship executable only with python3
* Thu Dec 15 2016 aloisio@gmx.com
- Added missing requirements
* Sat Sep  3 2016 aloisio@gmx.com
- Update to version 2.0.5
  * Fix addic7ed provider for some series name
  * Fix existing subtitles detection
  * Improve scoring
  * Add Docker container
  * Add .ogv video extension
* Sat Sep  3 2016 aloisio@gmx.com
- Update to version 2.0.4
  * Fix subscenter
* Fri Jun 10 2016 aloisio@gmx.com
- Update to version 2.0.3
  * Fix clearing cache in CLI
  version 2.0.2
  * Fix for dogpile.cache>=0.6.0
  * Fix missing sphinx_rtd_theme dependency
  version 2.0.1
  * Fix beautifulsoup4 minimal requirement
  version 2.0.0
  * Add refiners to enrich videos with information from
    metadata, tvdb and omdb
  * Add asynchronous provider search for faster searches
  * Add registrable managers so subliminal can run without
    install
  * Add archive support
  * Add the ability to customize scoring logic
  * Add an age argument to scan_videos for faster scanning
  * Add legendas.tv provider
  * Add shooter.cn provider
  * Improve matching and scoring
  * Improve documentation
  * Split nautilus integration into its own project
- Added auto-generated manfile
- Set up update-alternatives
* Wed Apr 27 2016 aloisio@gmx.com
- Added requires for python-futures
* Tue Apr 26 2016 dmueller@suse.com
- add provides/obsoletes
* Tue Apr 26 2016 aloisio@gmx.com
- Update to version 2.0rc1
- Dropped nautilus extension because it's no longer supplied
- Package renamed to python-subliminal in accordance
  with SUSE naming policy
* Fri Feb 26 2016 tbechtold@suse.com
- Require python-python-dateutil. package was renamed
* Wed Jan 20 2016 aloisio@gmx.com
- Added requirement for python-ndg-httpsclient to address
  security problem with urllib3 and python < 2.7.9
* Sun Jan  3 2016 aloisio@gmx.com
- Update to 1.1.1
  * Fix scanning videos on bad MKV files
  version 1.1
  * Fix library usage example in README
  * Fix for series name with special characters in addic7ed provider
  * Fix id property in thesubdb provider
  * Improve matching on titles
  * Add support for nautilus context menu with translations
  * Add support for searching subtitles in a separate directory
  * Add subscenter provider
  * Add support for python 3.5
- Removed subliminal-unicode_literals.patch included upstream
- Added nautilus integration script
* Thu Dec 10 2015 aloisio@gmx.com
- Backported commit 79fb044 (fixes #495) as
  subliminal-unicode_literals.patch
  * Prevents warnings related to click 5 and newer
* Sat Jul 25 2015 aloisio@gmx.com
- Update to version 1.0.1
  * Fix unicode issues in CLI (python 2 only)
  * Fix score scaling in CLI (python 2 only)
  * Improve error handling in CLI
  * Color collect report in CLI
  version 1.0:
  * Many changes and fixes
  * New test suite
  * New documentation
  * New CLI
- Added manpage
- Package now depends on python-click, python-pbr and python-six
- Added all Requires also as BuildRequires and aligned their
  versions with PyPI
* Fri May 22 2015 aloisio@gmx.com
- Update to current git version
  * Fix podnapisi provider
- Fixed build problem
* Thu Feb 26 2015 p.drouand@gmail.com
- Fix Group
- Fix dependencies
* Tue Feb 10 2015 aloisio@gmx.com
- Initial version 0.8.0_dev
